plot_ce_plane

report.plot_ce_plane(
    outcomes,
    *,
    comparator=None,
    wtp=None,
    effect=None,
    ax=None,
)

Scatter of incremental cost vs incremental effect per iteration.

Parameters

Name Type Description Default
outcomes Outcomes Outcomes from a probabilistic sensitivity analysis. required
comparator str | None Reference intervention (default: outcomes.comparator, or the first intervention if none was flagged). None
wtp float | None If given, draw the willingness-to-pay threshold line. None
effect str | None Effect column (default: primary). None
ax Axes | None Existing axes to draw on. None

Example

import pandas as pd from heormodel.models import Outcomes from heormodel.report import plot_ce_plane c = pd.DataFrame({“A”: [0.0, 1.0], “B”: [5.0, 6.0]}) e = pd.DataFrame({“A”: [0.0, 0.1], “B”: [0.5, 0.4]}) ax = plot_ce_plane(Outcomes.from_wide(c, e)) ax.get_xlabel() ‘Incremental effect (qaly)’